@@ -1,8 +1,6 @@
 #ifndef CONFIG_HPP
 #define CONFIG_HPP
 
-#include <iostream>
-#include <fstream>
 #include <string>
 #include <vector>
 
@@ -21,6 +19,8 @@ class Config
 public:
     static Config* getInstance();
 
+    const gchar *const getPath();
+
     // options
     bool show_calendar;
     bool show_timezones;
@@ -29,6 +29,8 @@ public:
     bool mark_today;
     string external_viewer;
     bool show_week_numbers;
+    bool close_on_unfocus;
+    string force_lang;
 
     bool mainwindow_decorated;
     bool mainwindow_keep_above;
@@ -36,6 +38,8 @@ public:
     bool mainwindow_skip_taskbar;
     bool mainwindow_resizable;
     GtkWindowPosition mainwindow_position;
+    int mainwindow_xoffset;
+    int mainwindow_yoffset;
 
 private:
     static Config* _instance;
@@ -44,14 +48,14 @@ private:
     template <class T> bool fromString(T& t, const string& s);
     string strip(string const& str);
 
-    std::ifstream file;
+    gchar* path;
 
 protected:
     explicit Config();
     ~Config();
 
-    void getDefaults();
-    bool getFile();
+    void setDefaults();
+    bool findPath();
     void readFile();
     void parseLine(string line);
     void addOption(string var, string val);
